//-*-c++-*-
#include "tulip/Selection.h"
#include "tulip/SuperGraph.h"
#include "tulip/SelectionProxy.h"

Selection::Selection (const PropertyContext & context):Property<BooleanType , BooleanType>(context) {
  selectionProxy=(SelectionProxy *)context.propertyProxy;
}

